summaryrefslogtreecommitdiffstats
path: root/kmail/headeritem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/headeritem.h')
-rw-r--r--kmail/headeritem.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/kmail/headeritem.h b/kmail/headeritem.h
index 4ada5112..1912d901 100644
--- a/kmail/headeritem.h
+++ b/kmail/headeritem.h
@@ -16,11 +16,11 @@
**
** In addition, as a special exception, the copyright holders give
** permission to link the code of this program with any edition of
-** the Qt library by Trolltech AS, Norway (or with modified versions
-** of Qt that use the same license as Qt), and distribute linked
+** the TQt library by Trolltech AS, Norway (or with modified versions
+** of TQt that use the same license as TQt), and distribute linked
** combinations including the two. You must obey the GNU General
** Public License in all respects for all of the code used other than
-** Qt. If you modify this file, you may extend this exception to
+** TQt. If you modify this file, you may extend this exception to
** your version of the file, but you are not obligated to do so. If
** you do not wish to do so, delete this exception statement from
** your version.
@@ -63,14 +63,14 @@ public:
mImperfectlyThreaded (true), mSubjThreadingList(0) { }
~SortCacheItem() { if(mUnsortedChildren) free(mUnsortedChildren); }
- /** The parent node of the item in the threading hierarchy. 0 if the item
- * is at top level, which is the default. Can only be set by parents. */
- SortCacheItem *parent() const { return mParent; }
+ /** The tqparent node of the item in the threading hierarchy. 0 if the item
+ * is at top level, which is the default. Can only be set by tqparents. */
+ SortCacheItem *tqparent() const { return mParent; }
/**
* Returs whether the item is so far imperfectly threaded.
* If an item is imperfectly threaded (by References or subject, not by
* In-Reply-To) it will be reevalutated when a new mail comes in. It could be
* the perfect parent. */
bool isImperfectlyThreaded() const
{ return mImperfectlyThreaded; }
/** Set whether the item is currently imperfectly threaded (by References
@@ -80,20 +80,20 @@ public:
/** Returns whether the item has other items below it. */
bool hasChildren() const
{ return mSortedChildren.count() || mUnsortedCount; }
- /** The sorted children are an array of sortcache items we know are below the
+ /** The sorted tqchildren are an array of sortcache items we know are below the
* current one and are already properly sorted (as read from the cache ) */
const TQPtrList<SortCacheItem> *sortedChildren() const
{ return &mSortedChildren; }
- /** The unsorted children are an array of sortcache items we know are below the
+ /** The unsorted tqchildren are an array of sortcache items we know are below the
* current one, but are yet to be threaded and sorted properly. */
SortCacheItem **unsortedChildren(int &count) const
{ count = mUnsortedCount; return mUnsortedChildren; }
- /** Add an item to this itme's list of already sorted children. */
+ /** Add an item to this itme's list of already sorted tqchildren. */
void addSortedChild(SortCacheItem *i) {
i->mParent = this;
mSortedChildren.append(i);
}
- /** Add an item to this itme's list of unsorted children. */
+ /** Add an item to this itme's list of unsorted tqchildren. */
void addUnsortedChild(SortCacheItem *i) {
i->mParent = this;
if(!mUnsortedChildren)
@@ -104,7 +104,7 @@ public:
mUnsortedChildren[mUnsortedCount++] = i;
}
- /** Clear the sorted and unsorted children datastructures. */
+ /** Clear the sorted and unsorted tqchildren datastructures. */
void clearChildren() {
mSortedChildren.clear();
free( mUnsortedChildren );
@@ -130,7 +130,7 @@ public:
void setOffset(int x) { mSortOffset = x; }
void updateSortFile( FILE *sortStream, KMFolder *folder,
- bool waiting_for_parent = false,
+ bool waiting_for_tqparent = false,
bool update_discovered_count = false);
/** Set the list of mails with a certain subject that this item is on.
@@ -163,8 +163,8 @@ private:
class HeaderItem : public KListViewItem
{
public:
- HeaderItem( TQListView* parent, int msgId, const TQString& key = TQString::null );
- HeaderItem( TQListViewItem* parent, int msgId, const TQString& key = TQString::null );
+ HeaderItem( TQListView* tqparent, int msgId, const TQString& key = TQString() );
+ HeaderItem( TQListViewItem* tqparent, int msgId, const TQString& key = TQString() );
~HeaderItem ();
/** Set the message id of this item, which is the offset/index in the folder
@@ -185,7 +185,7 @@ public:
// Return the serial number of the message associated with this item;
TQ_UINT32 msgSerNum() const;
- /** Expands all children of the list view item. */
+ /** Expands all tqchildren of the list view item. */
void setOpenRecursive( bool open );
/** Returns the text of the list view item. */
@@ -63,14 +63,14 @@ public:
* If an item is imperfectly threaded (by References or subject, not by
* In-Reply-To) it will be reevalutated when a new mail comes in. It could be
- * the perfect parent. */
+ * the perfect tqparent. */
bool isImperfectlyThreaded() const
{ return mImperfectlyThreaded; }